<?php

namespace Drupal\xray_audit\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager;
use Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for XrayAudit Task routes.
 */
class XrayAuditTaskController extends ControllerBase {

  /**
   * Plugin manager.
   *
   * @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager
   */
  protected $pluginManager;

  /**
   * Constructs of Controller.
   *
   * @param \Drupal\xray_audit\Plugin\XrayAuditTaskPluginManager $plugin_manager
   *   Plugin manager XrayAudit.
   */
  public function __construct(XrayAuditTaskPluginManager $plugin_manager) {
    $this->pluginManager = $plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin_manager.xray_audit_task')
    );
  }

  /**
   * Return a render array with the results of the task.
   *
   * @param string $group_plugin
   *   Group plugin.
   * @param string $task_plugin
   *   Task plugin.
   * @param string|null $operation
   *   Operation.
   *
   * @return array
   *   Render array.
   */
  public function build(string $group_plugin, string $task_plugin, string $operation = NULL): array {
    /** @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface $task_plugin */
    $task_plugin = $this->pluginManager->createInstance($task_plugin);
    if (!$task_plugin instanceof XrayAuditTaskPluginInterface) {
      return [];
    }
    $data = $task_plugin->getDataOperationResult($operation);
    return $task_plugin->buildDataRenderArray($data, $operation);
  }

  /**
   * Return a render array with the results of the task.
   *
   * @param string $group_plugin
   *   Group plugin.
   * @param string $task_plugin
   *   Task plugin.
   * @param string|null $operation
   *   Operation.
   *
   * @return string
   *   Title.
   */
  public function getTitle(string $group_plugin, string $task_plugin, string $operation = NULL): string {
    $title = '';
    /** @var \Drupal\xray_audit\Plugin\XrayAuditTaskPluginInterface $task_plugin */
    $task_plugin = $this->pluginManager->createInstance($task_plugin);
    if (!$task_plugin instanceof XrayAuditTaskPluginInterface) {
      return $title;
    }
    $title .= $task_plugin->label();
    if ($operation) {
      $title = $task_plugin->getOperations()[$operation]['label'] ?? $task_plugin->label();
    }
    return $title;
  }

}
